# Dataset: Learning to Solve Large-Scale SCUC

This package contains the instance data used for the experiments presented in the paper *Learning to Solve Large-Scale Security-Constrained Unit Commitment Problems*, by Alinson S. Xavier, Feng Qiu and Shabbir Ahmed.

## Unit commitment instances

Each instance is described by three files: `buses.csv`, `generator.csv` and `lines.csv`.

The file `generators.csv` describes the units in the system. It has the following columns:

* **Unit:** Unique unit identifier.
* **Min Power:** Minimum power produced by the unit if it is operational (in MW).
* **Max Power:** Maximum power produced by the unit (in MW).
* **Ramp Up Limit:** Maximum increase in production from one time period to the next (in MW). For example, if the unit is producing 100 MW at time 1 and if this parameter is set to 40 MW, then the unit will produce at most 140 MW at time 2. 
* **Ramp Down Limit:** Maximum decrease in production from one time period to the next (in MW). For example, if the unit is producing 100 MW at time 1 and this parameter is set to 40 MW, then the unit will produce at least 60 MW at time 2.
* **Startup Ramp Limit:** Maximum amount of power (in MW) this unit can provide at time `t` if the unit starts up at time `t`.
* **Shutdown Ramp Limit:** Maximum amount of power (in MW) this unit can provide at time `t` if the unit shuts down at time `t+1`.
* **Initial state:** Not currently used.
* **Bus:** Identifier of the bus where this unit is located.
* **Always on:** Not currently used.
* **Minimum Uptime:** Minimum amount of time the unit must stay operational after starting up (in hours). For example, if the unit starts up at time 1 and `Minimum Uptime` is set to 4, then the unit can only shut down at time 5.
* **Minimum Downtime:** Minimum amount of time the unit must stay offline after shutting down (in hours). For example, if the unit shuts down at time 1 and `Minimum Downtime` is set to 4, then the unit can only start producing power again at time 5.
* **Price Min Power:** Cost to keep the unit on, producing at its minimum level (in dollars).
* **Price Segment** and **Offer Segment:** Parameters describing the incremental piecewise-linear production costs. For example, suppose `Min Power` is 100 MW, `Price Min Power` is 50.0, `Offer Segment` is `[10.0, 20.0, 5.0]` and `Price Segment` is `[1.0, 2.0, 3.0]`. The production costs at 100 MW, 110 MW, 130 MW and 135 MW are, respectively, 50, 60, 100 and 115. For other points, the cost is a linear interpolation of these values.
* **Startup Cost:** Cost to turn the unit on (in dollars).    


The file `lines.csv` describes the transmission network. It has the following columns:

* **Line:** Unique transmission line identifier.
* **Source:** Identifier of the bus where the transmission line originates.
* **Target:** Identifier of the bus where the transmission line goes to.
* **Reactance:** Reactance of the transmission line (in ohms).
* **Normal Flow Limit:** Maximum amount of power (in MW) allowed to flow through the line when the system is in its regular, fully-operational state.
* **Emergency Flow Limit:**  Maximum amount of power (in MW) allowed to flow through the line when the system is in degraded state (for example, after the failure of another transmission line).
* **Vulnerable?** If `1`, a contingency affecting this transmission line is considered credible, and the N-1 contingency screening algorithm should consider the removal of this line. If `0`, the line is considered safe.
* **Zone:** Not currently used.

The file `buses.csv` describes the buses in the network. It has the following columns:

* **Bus:** Unique bus identifier.
* **Load Percentage (%):** How much percent of the total system load comes from this particular bus. This column sums to 100.

## Load profile data

As explained in Subsection 4.2 of the paper, peak system load and temporal load profiles were generated based on an analysis of publicly available data from PJM, corresponding to the month of January, 2017. The file `load_profiles/pjm-jan2017.csv` contains a summary of that analysis. For each hour of the day, the CSV presents:

* **Absolute:** The average system load (in MW).
* **Multiplier:** The relative change in average system load when compared to the previous time period. For example, if the absolute system load was 100 MW at time 1 and 150 MW at time 2, then the multiplier for time 2 is 1.5. This corresponds to variable mu in the paper. 
* **Multiplier Stdev:** For each particular day of January 2017, the relative change in system load from hour to hour is slightly different. While the previous column shows the average multipliers, this column shows the standard deviations. This corresponds to variable sigma in the paper.